@@ -13,7 +13,7 @@ if [ "$1" ]; then
 	fi
 fi
 
-MY_BDA=`hciconfig hci0|grep Address|awk '{ print $3 }'`
+MY_BDA=`cat /sys/class/bluetooth/hci0/address`
 
 [ -z "$MY_BDA" ] && exit 1
 
@@ -26,15 +26,7 @@ if [ "$OLD_DIR" ]; then
 	mv $OLD_DIR $CORRECT_DIR
 fi
 
-MODE = ""
-
-if [ -f "$CORRECT_DIR/config" ]; then
-	MODE=`egrep ^mode $CORRECT_DIR/config|awk '{ print $2 }'`
-fi
-
-if [ "$MODE" ]; then
-	dbus-send --system --dest=org.bluez /org/bluez/hci0 org.bluez.Adapter.SetMode string:$MODE
-fi
+dbus-send --system --print-reply --dest=org.bluez /org/bluez/hci0 org.bluez.Adapter.SetMode string:connectable > /dev/null
 
 NAME=""
 
@@ -47,5 +39,16 @@ if [ -z "$NAME" ] && [ -f "$CORRECT_DIR/config" ]; then
 fi
 
 if [ "$NAME" ]; then
-	dbus-send --system --dest=org.bluez /org/bluez/hci0 org.bluez.Adapter.SetName string:"$NAME"
+	dbus-send --print-reply --system --dest=org.bluez /org/bluez/hci0 org.bluez.Adapter.SetName string:"$NAME" > /dev/null
 fi
+
+MODE=""
+
+if [ -f "$CORRECT_DIR/config" ]; then
+	MODE=`egrep ^mode $CORRECT_DIR/config|awk '{ print $2 }'`
+fi
+
+if [ "$MODE" ]; then
+	dbus-send --print-reply --system --dest=org.bluez /org/bluez/hci0 org.bluez.Adapter.SetMode string:$MODE > /dev/null
+fi
+
